Module cookie

Module cookie 

type extractor and responder for cookies.

Structs

Cookie
Representation of an HTTP cookie.
CookieJar
container of cookies extracted from request.
ExtensionKey
an extractor type wrapping around Key hinting itself can be extracted from request extensions. See WebRequest::extensions for run time state management.
Key
A cryptographic master key for use with Signed and/or Private jars.
Private
encrypted cookie container type. must annotate the generic type param with types that can provide the key for encryption. See StateKey and ExtensionKey for detail.
Signed
encrypted cookie container type. must annotate the generic type param with types that can provide the key for encryption. See StateKey and ExtensionKey for detail.
StateKey
an extractor type wrapping around Key hinting itself can be extracted from application state. See App::with_state for compile time state management.

Enums

ParseError
Enum corresponding to a parsing error.