Module form

Module form 

Structs

Form
Extract type for form object. const generic param LIMIT is for max size of the object in bytes. Object larger than limit would be treated as error.
LazyForm
lazy deserialize type. it lowers the deserialization to handler function where zero copy deserialize can happen.

Constants

DEFAULT_LIMIT