pub struct Form<T, const LIMIT: usize = DEFAULT_LIMIT>(pub T);Expand description
Extract type for form object. const generic param LIMIT is for max size of the object in bytes. Object larger than limit would be treated as error.
Default limit is DEFAULT_LIMIT in bytes.
Tuple Fields
0: TTrait Implementations
Sourceimpl<'a, 'r, C, B, T, const LIMIT: usize> FromRequest<'a, WebContext<'r, C, B>> for Form<T, LIMIT>
impl<'a, 'r, C, B, T, const LIMIT: usize> FromRequest<'a, WebContext<'r, C, B>> for Form<T, LIMIT>