GrpcStreamResponse

Struct GrpcStreamResponse 

pub struct GrpcStreamResponse<T> { /* private fields */ }
Body type for gRPC responses. Yields encoded gRPC data frames and trailers.

Implementations

Source

impl<T> ResponseBody<T>

pub fn once(msg: T) -> ResponseBody<T>

Create a response body that yields a single message then trailers.

pub fn channel() -> (ResponseSender<T>, ResponseBody<T>)

Create a response body backed by a channel for streaming multiple messages.

pub fn initial_metadata(self, headers: HeaderMap) -> ResponseBody<T>

Set initial metadata (response headers) sent alongside the response.

pub fn trailing_metadata(self, trailers: HeaderMap) -> ResponseBody<T>

Set trailing metadata merged into the final trailers frame.

These are combined with grpc-status. Trailers pushed via ResponseSender::send_trailers are appended on top.

pub fn take_initial_metadata(&mut self) -> Option<HeaderMap>

Take initial metadata headers, if set.

pub fn into_response(self, req: Request<()>) -> Response<ResponseBody<T>>

Convert self into a Response type where self is as the body. Take in the request it belongs to for potential compression header preparation.