Module state

Module state 

type extractor or application state.

Structs

StateOwn
App state extractor for owned value. S type must be the same with the type passed to App::with_xxx_state(S).
StateRef
App state extractor. S type must be the same with the type passed to App::with_xxx_state(S).

Traits

BorrowState
borrow trait for extracting typed field from application state