pub struct LimitBody<B> { /* private fields */ }Trait Implementations
Sourceimpl<B> Body for LimitBody<B>where
B: BodyStream,
impl<B> Body for LimitBody<B>where
B: BodyStream,
Sourcetype Error = Box<dyn Error + Sync + Send>
type Error = Box<dyn Error + Sync + Send>
The error type that can occur while producing frames.
Sourcefn poll_frame(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
) -> Poll<Option<Result<Frame<Self::Data>, Self::Error>>>
fn poll_frame( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<Option<Result<Frame<Self::Data>, Self::Error>>>
Attempt to pull the next frame from the body. Read more
Sourcefn is_end_stream(&self) -> bool
fn is_end_stream(&self) -> bool
Indicates whether the body has been fully consumed. Read more
impl<'__pin, B> Unpin for LimitBody<B>where
PinnedFieldsOf<__Origin<'__pin, B>>: Unpin,