pub struct RateLimit(/* private fields */);Expand description
builder for client ip address based rate limiting middleware.
Examples
App::new()
.at("/", get(handler_service(|| async { "hello,world!" })))
// rate limit to 60 rps for one ip address.
.enclosed(RateLimit::per_minute(60));Implementations
Sourceimpl RateLimit
impl RateLimit
Sourcepub fn per_second(max_burst: u32) -> Self
pub fn per_second(max_burst: u32) -> Self
Construct a RateLimit for a number of cells per_second period. The given number of cells is also assumed to be the maximum burst size.
Panics
- When max_burst is zero.
Sourcepub fn per_minute(max_burst: u32) -> Self
pub fn per_minute(max_burst: u32) -> Self
Construct a RateLimit for a number of cells per_minute period. The given number of cells is also assumed to be the maximum burst size.
Panics
- When max_burst is zero.
Sourcepub fn per_hour(max_burst: u32) -> Self
pub fn per_hour(max_burst: u32) -> Self
Construct a RateLimit for a number of cells per_hour period. The given number of cells is also assumed to be the maximum burst size.
Panics
- When max_burst is zero.
Sourcepub fn with_period(replenish_1_per: Duration) -> Self
pub fn with_period(replenish_1_per: Duration) -> Self
Construct a RateLimit that replenishes one cell in a given interval.
Panics
- When the Duration is zero.