pub struct CatchUnwind;Expand description
middleware for catching panic inside Service::call and return a 500 error response.
Examples:
// handler function that cause panic.
async fn handler(_: &WebContext<'_>) -> &'static str {
panic!("");
}
App::new()
// request to "/" would always panic due to handler function.
.at("/", handler_service(handler))
// enclosed application with CatchUnwind middleware.
// panic in handler function would be caught and converted to 500 internal server error response to client.
.enclosed(CatchUnwind);
// CatchUnwind can also be used on individual route service for scoped panic catching:
App::new()
.at("/", handler_service(handler))
// only catch panic on "/scope" path.
.at("/scope", handler_service(handler).enclosed(CatchUnwind));Trait Implementations
Sourceimpl Clone for CatchUnwind
impl Clone for CatchUnwind
Sourcefn clone(&self) -> CatchUnwind
fn clone(&self) -> CatchUnwind
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Arg> Service<Arg> for CatchUnwindwhere
CatchUnwind: Service<Arg>,
impl<Arg> Service<Arg> for CatchUnwindwhere
CatchUnwind: Service<Arg>,