pub struct TowerHttpCompat<L>(/* private fields */);Expand description
A middleware type that bridge xitca-service and tower-service.
Any tower-http type that impl Layer trait can be passed to it and used as xitca-web’s middleware.
Type mutation
TowerHttpCompat would mutate response body type from B to CompatBody<ResB>. Service enclosed
by it must be able to handle it’s mutation or utilize TypeEraser to erase the mutation.
Implementations
Sourceimpl<L> TowerHttpCompat<L>
impl<L> TowerHttpCompat<L>
Sourcepub const fn new(layer: L) -> Self
pub const fn new(layer: L) -> Self
Construct a new xitca-web middleware from tower-http layer type.
Limitation:
tower::Service::poll_ready implementation is ignored by TowerHttpCompat. if a tower Service is sensitive to poll_ready implementation it should not be used.
Example:
use xitca_web::middleware::tower_http_compat::TowerHttpCompat;
use tower_http::set_status::SetStatusLayer;
App::new()
.at("/", fn_service(handler))
.enclosed(TowerHttpCompat::new(SetStatusLayer::new(StatusCode::NOT_FOUND)));