Route

Struct Route 

pub struct Route<R, N, const M: usize> { /* private fields */ }
a tree type able of routing multiple Method against multiple Service types in linear manner.

Implementations

Source

impl<const M: usize> Route<(), MethodNotAllowedBuilder<()>, M>

pub const fn new( methods: [Method; M], ) -> Route<(), MethodNotAllowedBuilder<()>, M>

construct a new Route with given array of methods.

Panics

panic when input array is zero length.

pub fn route<R>(self, route: R) -> Route<R, MethodNotAllowedBuilder<R>, M>

pass certain Service type to Route so it can be matched against the methods Route contains.

Source

impl<R, N, const M: usize> Route<R, N, M>

pub fn next<R1, const M1: usize>( self, next: Route<R1, MethodNotAllowedBuilder<R1>, M1>, ) -> Route<R, Route<R1, N, M1>, M>

append another Route to existing Route type.

Panics

panic when chained Routes contain overlapping Method. Route only do liner method matching and overlapped method(s) will always enter the first Route matched against.

pub fn get<R1>(self, get: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::GET guarded route to current Route. Act as a shortcut of Route::next.

pub fn post<R1>(self, post: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::POST guarded route to current Route. Act as a shortcut of Route::next.

pub fn put<R1>(self, put: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::PUT guarded route to current Route. Act as a shortcut of Route::next.

pub fn delete<R1>(self, delete: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::DELETE guarded route to current Route. Act as a shortcut of Route::next.

pub fn head<R1>(self, head: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::HEAD guarded route to current Route. Act as a shortcut of Route::next.

pub fn options<R1>(self, options: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::OPTIONS guarded route to current Route. Act as a shortcut of Route::next.

pub fn connect<R1>(self, connect: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::CONNECT guarded route to current Route. Act as a shortcut of Route::next.

pub fn patch<R1>(self, patch: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::PATCH guarded route to current Route. Act as a shortcut of Route::next.

pub fn trace<R1>(self, trace: R1) -> Route<R, Route<R1, N, 1>, M>

appending Method::TRACE guarded route to current Route. Act as a shortcut of Route::next.