pub struct Grpc<T, const LIMIT: usize = DEFAULT_LIMIT>(pub T);Expand description
Extract and response type for unary gRPC messages.
As an extractor, decodes the gRPC length-prefixed wire format (1 byte compression flag + 4 byte big-endian length + protobuf payload) from the request body.
As a responder, encodes the protobuf message with gRPC framing and appends grpc-status: 0
trailers.
Const generic LIMIT controls the maximum request body size in bytes. Default is DEFAULT_LIMIT.
Tuple Fields
0: TTrait Implementations
Sourceimpl<'a, 'r, C, B, T, const LIMIT: usize> FromRequest<'a, WebContext<'r, C, B>> for Grpc<T, LIMIT>
impl<'a, 'r, C, B, T, const LIMIT: usize> FromRequest<'a, WebContext<'r, C, B>> for Grpc<T, LIMIT>
Sourceimpl<'r, C, B, T, const LIMIT: usize> Responder<WebContext<'r, C, B>> for Grpc<T, LIMIT>
impl<'r, C, B, T, const LIMIT: usize> Responder<WebContext<'r, C, B>> for Grpc<T, LIMIT>