pub struct GrpcStreamResponse<T> { /* private fields */ }Expand description
Body type for gRPC responses. Yields encoded gRPC data frames and trailers.
Implementations
Sourceimpl<T> ResponseBody<T>
impl<T> ResponseBody<T>
Sourcepub fn once(msg: T) -> ResponseBody<T>
pub fn once(msg: T) -> ResponseBody<T>
Create a response body that yields a single message then trailers.
Sourcepub fn channel() -> (ResponseSender<T>, ResponseBody<T>)
pub fn channel() -> (ResponseSender<T>, ResponseBody<T>)
Create a response body backed by a channel for streaming multiple messages.
Sourcepub fn initial_metadata(self, headers: HeaderMap) -> ResponseBody<T>
pub fn initial_metadata(self, headers: HeaderMap) -> ResponseBody<T>
Set initial metadata (response headers) sent alongside the response.
Sourcepub fn trailing_metadata(self, trailers: HeaderMap) -> ResponseBody<T>
pub fn trailing_metadata(self, trailers: HeaderMap) -> ResponseBody<T>
Set trailing metadata merged into the final trailers frame.
These are combined with grpc-status. Trailers pushed via ResponseSender::send_trailers
are appended on top.
Sourcepub fn take_initial_metadata(&mut self) -> Option<HeaderMap>
pub fn take_initial_metadata(&mut self) -> Option<HeaderMap>
Take initial metadata headers, if set.
Sourcepub fn into_response(self, req: Request<()>) -> Response<ResponseBody<T>>
pub fn into_response(self, req: Request<()>) -> Response<ResponseBody<T>>
Convert self into a Response type where self is as the body.
Take in the request it belongs to for potential compression header preparation.