type extractor or application state.
Structs
- State
Own - App state extractor for owned value. S type must be the same with the type passed to App::with_xxx_state(S).
- State
Ref - App state extractor. S type must be the same with the type passed to App::with_xxx_state(S).
Traits
- Borrow
State - borrow trait for extracting typed field from application state