pub struct RequestExt<B> { /* private fields */ }Expand description
extension types for Request
Implementations
Sourceimpl<B> RequestExt<B>
impl<B> RequestExt<B>
Sourcepub fn socket_addr(&self) -> &SocketAddr
pub fn socket_addr(&self) -> &SocketAddr
retrieve remote peer’s socket address.
Default
std::net::Ipv4Addr::UNSPECIFIED is used for representing peers that can’t provide it’s socket address.
Sourcepub fn socket_addr_mut(&mut self) -> &mut SocketAddr
pub fn socket_addr_mut(&mut self) -> &mut SocketAddr
exclusive version of RequestExt::socket_addr
pub fn protocol(&self) -> Option<Protocol>
Sourcepub fn map_body<F, B1>(self, func: F) -> RequestExt<B1>where
F: FnOnce(B) -> B1,
pub fn map_body<F, B1>(self, func: F) -> RequestExt<B1>where
F: FnOnce(B) -> B1,
map body type of self to another type with given function closure.
Sourcepub fn replace_body<B1>(self, body: B1) -> (RequestExt<B1>, B)
pub fn replace_body<B1>(self, body: B1) -> (RequestExt<B1>, B)
replace body type of self with another type and return new type of Self and original body type in tuple.