BoxedServiceObject

Type Alias BoxedServiceObject 

pub type BoxedServiceObject<Req, Res, Err> = Box<dyn ServiceObject<Req, Response = Res, Error = Err>>;
An often used type alias for boxed service object. used when Req type is not bound to any lifetime.

Aliased Type

pub struct BoxedServiceObject<Req, Res, Err>(/* private fields */);